jQuery UI Dialog - Modal message

Your files have downloaded successfully into the My Downloads folder.

Currently using 36% of your storage space.

Sed vel diam id libero rutrum convallis. Donec aliquet leo vel magna. Phasellus rhoncus faucibus ante. Etiam bibendum, enim faucibus aliquet rhoncus, arcu felis ultricies neque, sit amet auctor elit eros a lectus.

checkbox
radio
textarea

Use a modal dialog to explicitly acknowledge information or an action before continuing their work. Set the `modal` option to true, and specify a primary action (Ok) with the `buttons` option.